#!/usr/bin/env python3
# MIT License
# Copyright (c) 2021 Sergey B <dkc.sergey.88@hotmail.com>


from . import ir_light_bulb, color_detect, image_compose
from logging import log, INFO, DEBUG, ERROR, basicConfig
import argparse
import os
from sys import stdout
import subprocess
import time
import shutil
from systemd.daemon import notify, Notification
import signal
import configparser
from .snapshot_bcm import ffi, lib

irsend_exe = "irsend"
run = True


def signals_handler(signum, frame):
    global run
    run = False


def main():
    """ambibulb execution entry point."""

    global run
    signal.signal(signal.SIGINT, signals_handler)
    signal.signal(signal.SIGTERM, signals_handler)

    if shutil.which(irsend_exe) is None:
        log(
            ERROR,
            "lirc is not installed, please run: " + "apt install lirc",
        )
        return

    # parse input arguments
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-c",
        "--config_path",
        help="path to config ini file",
        type=str,
        default=os.path.join(
            os.path.dirname(os.path.realpath(__file__)), "ambibulb-config.ini"
        ),
    )
    args = parser.parse_args()

    if not os.path.exists(args.config_path):
        log(
            ERROR,
            "couldn't find config ini file: "
            + args.config_path
            + ". Please run ambibulb-config to create it.",
        )
        return

    params = configparser.ConfigParser()
    params.read(args.config_path)

    basicConfig(level=int(params["general"]["logging_level"]))

    bulb = ir_light_bulb.EightyStateIRLightBulb(
        params["general"].getboolean("with_white"), params["lirc"]["config_id"]
    )

    cycle_period = float(params["general"]["cycle_period"])
    cycle_period_now = 0.0

    cropping_mode = image_compose.CroppingMode(
        params["general"]["cropping_mode"]
    )

    # init screenshot module
    lib.snapshot_bcm_init()
    screenshot = lib.snapshot_bcm_init_snapshot()

    # systemd notification
    notify(Notification.READY)

    try:
        while run:
            # wait if current cycle period is less then defined
            sleep_time = cycle_period - cycle_period_now
            if (sleep_time) > 0.0:
                time.sleep(sleep_time)

            screen_tic = time.perf_counter()

            # take a screenshot of dispaly
            log(DEBUG, "_____________________")
            lib.snapshot_bcm_take_snapshot(screenshot)
            raw_image = ffi.buffer(screenshot.buffer, screenshot.size)

            screen_toc = time.perf_counter()
            log(
                DEBUG,
                "screenshot time: "
                + "{:10.4f}".format(screen_toc - screen_tic),
            )

            # compose image
            compoed_image = image_compose.image_compose(
                raw_image,
                screenshot.width,
                screenshot.height,
                cropping_mode
            )

            # calculate dominant color
            color_r, color_g, color_b = color_detect.get_dominant_clr(
                compoed_image
            )

            # change curent light bulb state
            bulb.change_state(color_r, color_g, color_b)

            new_state_tic = time.perf_counter()
            cycle_period_now = new_state_tic - screen_tic
            log(
                DEBUG,
                "cycle time: " + "{:10.4f}".format(cycle_period_now),
            )

    finally:
        notify(Notification.STOPPING)
        log(INFO, "finishing...")
        lib.snapshot_bcm_free_snapshot(screenshot)
        lib.snapshot_bcm_free()


if __name__ == "__main__":
    main()



# MIT License
# Copyright (c) 2021 Sergey B <dkc.sergey.88@hotmail.com>


from logging import log, INFO, DEBUG
import subprocess
import time


class EightyStateIRLightBulb:
    """Class holds color state of IR light bulb.

    This class holds and changes light state of a LED RBG bulb.
    The changinng happend based on input color (RGB position).
    Algoritm calculates the shortest distance amonhg 80
    possible light bulb color states and input color on RGB plane.

    Attributes:
        brightess_clr_to_positions: dict among the light bulb color states
            and appropriate points on RGB plane.
        init_brightess_clr_to_positions: initialized instance of
            brightess_clr_to_positions attribute.
        brightness_values: possible values of brightess parameter for irsend.
        color_values: possible values of brightess parameter for irsend.
        with_white: the flag defines if white color will be used.
        br_state: current brightess state of the light bulb.
        off: the flag defines if the light bulb is OFF.
        clr_state: current color state of the light bulb.
        sender_proc: irsend process execution object.
        lirc_source_id: lirc config name.
    """

    brightess_clr_to_positions = {
        (0, "BLACK"): [(18, 18, 18)],
        (1, "RED"): [(51, 14, 14)],
        (1, "ORANGE"): [(51, 21, 14)],
        (1, "YELLOW_DARK"): [(51, 24, 14)],
        (1, "YELLOW_GREENISH"): [(51, 35, 14)],
        (1, "YELLOW"): [(51, 42, 14)],
        (1, "GREEN"): [(24, 91, 14), (14, 91, 14)],
        (1, "TURQUOISE"): [(22, 51, 33)],
        (1, "TURQUOISE_LIGHT"): [(22, 38, 51)],
        (1, "BLUE_LIGHT"): [(22, 38, 51)],
        (1, "BLUE_PASTEL"): [(22, 31, 51)],
        (1, "BLUE"): [(14, 14, 51)],
        (1, "BLUE_PURPLE"): [(27, 14, 51)],
        (1, "PURPLE"): [(35, 22, 51)],
        (1, "PURPLE_PINKISH"): [(44, 22, 51)],
        (1, "PINK"): [(51, 22, 51)],
        (1, "WHITE"): [(51, 51, 51), (51, 42, 37)],
        (2, "RED"): [(92, 25, 25)],
        (2, "ORANGE"): [(92, 39, 25)],
        (2, "YELLOW_DARK"): [(92, 49, 25)],
        (2, "YELLOW_GREENISH"): [(92, 62, 25)],
        (2, "YELLOW"): [(92, 75, 25)],
        (2, "GREEN"): [(49, 131, 25), (25, 131, 25)],
        (2, "TURQUOISE"): [(40, 92, 60)],
        (2, "TURQUOISE_LIGHT"): [(22, 51, 43)],
        (2, "BLUE_LIGHT"): [(40, 69, 92)],
        (2, "BLUE_PASTEL"): [(40, 56, 92)],
        (2, "BLUE"): [(25, 25, 92)],
        (2, "BLUE_PURPLE"): [(49, 25, 92)],
        (2, "PURPLE"): [(62, 40, 92)],
        (2, "PURPLE_PINKISH"): [(79, 40, 92)],
        (2, "PINK"): [(92, 40, 92)],
        (2, "WHITE"): [(92, 92, 92), (92, 75, 66)],
        (3, "RED"): [(133, 36, 36)],
        (3, "ORANGE"): [(133, 56, 36)],
        (3, "YELLOW_DARK"): [(133, 71, 36)],
        (3, "YELLOW_GREENISH"): [(133, 90, 36)],
        (3, "YELLOW"): [(133, 108, 36)],
        (3, "GREEN"): [(71, 133, 36), (36, 133, 36)],
        (3, "TURQUOISE"): [(58, 133, 87)],
        (3, "TURQUOISE_LIGHT"): [(40, 92, 77)],
        (3, "BLUE_LIGHT"): [(58, 99, 133)],
        (3, "BLUE_PASTEL"): [(58, 81, 133)],
        (3, "BLUE"): [(36, 36, 132)],
        (3, "BLUE_PURPLE"): [(71, 36, 133)],
        (3, "PURPLE"): [(90, 58, 133)],
        (3, "PURPLE_PINKISH"): [(146, 58, 133)],
        (3, "PINK"): [(132, 58, 132)],
        (3, "WHITE"): [(132, 132, 132), (133, 108, 95)],
        (4, "RED"): [(173, 47, 47)],
        (4, "ORANGE"): [(173, 73, 47)],
        (4, "YELLOW_DARK"): [(173, 93, 47)],
        (4, "YELLOW_GREENISH"): [(173, 117, 47)],
        (4, "YELLOW"): [(173, 142, 47)],
        (4, "GREEN"): [(93, 173, 47), (47, 173, 47)],
        (4, "TURQUOISE"): [(75, 173, 113)],
        (4, "TURQUOISE_LIGHT"): [(75, 173, 146)],
        (4, "BLUE_LIGHT"): [(75, 130, 173)],
        (4, "BLUE_PASTEL"): [(75, 105, 173)],
        (4, "BLUE"): [(47, 47, 173)],
        (4, "BLUE_PURPLE"): [(93, 47, 173)],
        (4, "PURPLE"): [(117, 75, 173)],
        (4, "PURPLE_PINKISH"): [(150, 75, 173)],
        (4, "PINK"): [(173, 75, 173)],
        (4, "WHITE"): [(173, 173, 173), (173, 142, 125)],
        (5, "RED"): [(214, 58, 58)],
        (5, "ORANGE"): [(214, 90, 58)],
        (5, "YELLOW_DARK"): [(214, 115, 58)],
        (5, "YELLOW_GREENISH"): [(214, 145, 58)],
        (5, "YELLOW"): [(214, 175, 58)],
        (5, "GREEN"): [(115, 214, 58), (58, 214, 58)],
        (5, "TURQUOISE"): [(93, 214, 140)],
        (5, "TURQUOISE_LIGHT"): [(93, 214, 180)],
        (5, "BLUE_LIGHT"): [(93, 160, 214)],
        (5, "BLUE_PASTEL"): [(93, 130, 214)],
        (5, "BLUE"): [(58, 58, 214)],
        (5, "BLUE_PURPLE"): [(115, 58, 214)],
        (5, "PURPLE"): [(145, 58, 214)],
        (5, "PURPLE_PINKISH"): [(185, 58, 214)],
        (5, "PINK"): [(214, 58, 214)],
        (5, "WHITE"): [(214, 214, 214), (214, 175, 154)],
    }

    brightness_values = range(6)
    color_values = (
        "RED",
        "ORANGE",
        "YELLOW_DARK",
        "YELLOW_GREENISH",
        "YELLOW",
        "GREEN",
        "TURQUOISE",
        "TURQUOISE_LIGHT",
        "BLUE_LIGHT",
        "BLUE_PASTEL",
        "BLUE",
        "BLUE_PURPLE",
        "PURPLE",
        "PURPLE_PINKISH",
        "PINK",
        "WHITE",
        "BLACK",
    )

    def __init__(self, with_white, lirc_source_id):
        """Initialize the instance of the class.

        To syncronize real light bulb color state,
            initialized with border parameters.

        Args:
            with_white: the flag defines if white color will be used.
            lirc_source_id: lirc source id, lirc.conf is available as name.
        """

        self.init_brightess_clr_to_positions = (
            EightyStateIRLightBulb.brightess_clr_to_positions
        )

        # remove white color points
        if not with_white:
            keys_to_remove = [
                (5, "WHITE"),
                (4, "WHITE"),
                (3, "WHITE"),
                (2, "WHITE"),
                (1, "WHITE"),
            ]
            for key_to_remove in keys_to_remove:
                if key_to_remove in self.init_brightess_clr_to_positions:
                    del self.init_brightess_clr_to_positions[key_to_remove]

        # initial bulb state
        self.br_state = 5
        self.off = False
        self.clr_state = "WHITE"
        self.sender_proc = None
        self.lirc_source_id = lirc_source_id

    def __action_detector(self, red_c, green_c, blue_c):
        """calculates required color and brightness.

        Args:
            red_c: input red color position.
            green_c: input green color position.
            blue_c: input blue color position.
        Returns:
            tuple(int, str): required color and brightness states.
        """
        log(
            DEBUG,
            "new color: "
            + str(red_c)
            + ":"
            + str(green_c)
            + ":"
            + str(blue_c),
        )

        brightess = None
        clr = None
        min_distance = None
        for (
            brightess_clr,
            positions,
        ) in self.init_brightess_clr_to_positions.items():
            for position in positions:
                cur_distance = (red_c - position[0]) ** 2
                cur_distance += (green_c - position[1]) ** 2
                cur_distance += (blue_c - position[2]) ** 2

                if min_distance is None or cur_distance < min_distance:
                    min_distance = cur_distance
                    brightess = brightess_clr[0]
                    clr = brightess_clr[1]

        log(DEBUG, "new brightnes: " + str(brightess))
        log(DEBUG, "new color: " + clr)
        return brightess, clr

    def __change_brightnes_cmds(self, new_state):
        """generates irsend commands to change brightness state.

        Args:
            new_state: required brightness state to change.
        Returns:
            set(str): commands to change the brightness.
        """
        if new_state not in EightyStateIRLightBulb.brightness_values:
            raise ValueError("Unexpected value")
        commands = []
        # control off-on parameter
        if new_state == 0 and self.off == False:
            self.off = True
            commands.extend(["TURN_OFF"])
        elif new_state != 0 and self.off == True:
            self.off = False
            commands.extend(["TURN_ON"])

        # control brightness level parameter
        if self.br_state != new_state and self.off == False:
            diff = self.br_state - new_state
            for _ in range(abs(diff)):
                if diff < 0:
                    commands.extend(["HIGHER"])
                else:
                    commands.extend(["LOWER"])
            log(DEBUG, "new brightnes state: " + str(new_state))
            self.br_state = new_state
        return commands

    def __change_color_cmds(self, new_state):
        """generates irsend commands to change color state.

        Args:
            new_state: required color state to change.
        Returns:
            set(str): commands to change the color.
        """
        if new_state not in EightyStateIRLightBulb.color_values:
            raise ValueError("Unexpected value")
        commands = []
        if self.clr_state != new_state and new_state != "BLACK":
            commands.extend([new_state])
            log(DEBUG, "new color state: " + str(new_state))
            self.clr_state = new_state
        return commands

    def change_state(self, red_c, green_c, blue_c):
        """changes the current state of the LED RBG bulb.

        Args:
            red_c: input red color position.
            green_c: input green color position.
            blue_c: input blue color position.
        """
        action_tic = time.perf_counter()
        # detect required BULB state changes
        new_br_state, new_clr_state = self.__action_detector(
            red_c, green_c, blue_c
        )
        action_toc = time.perf_counter()
        log(
            DEBUG,
            "action detection time: "
            + "{:10.4f}".format(action_toc - action_tic),
        )
        codes = []
        # get color brightnes cmds
        codes.extend(self.__change_brightnes_cmds(new_br_state))
        # if does not come TURN_OFF brightness
        if new_br_state != 0:
            # get color change cmds
            codes.extend(self.__change_color_cmds(new_clr_state))

        # there are codes to apply
        if len(codes) != 0:
            terminal_cmd = ["irsend", "SEND_ONCE", self.lirc_source_id]
            terminal_cmd.extend(codes)
            log(INFO, "codes: " + " ".join(map(str, terminal_cmd)))
            # wait prev. process to finish
            if self.sender_proc is not None:
                self.sender_proc.communicate()
            # send new ir changes
            self.sender_proc = subprocess.Popen(terminal_cmd)
        send_tic = time.perf_counter()
        log(
            DEBUG,
            "send actions time: " + "{:10.4f}".format(send_tic - action_toc),
        )



#!/usr/bin/env python3
# MIT License
# Copyright (c) 2021 Sergey B <dkc.sergey.88@hotmail.com>


import sys
import os, subprocess
from whiptail import Whiptail
import configparser
from shutil import copyfile
from . import image_compose


config_path = os.path.join(
    os.path.dirname(os.path.realpath(__file__)), "ambibulb-config.ini"
)

w = Whiptail(title="Ambibulb configuration.")

lirc_confpath_id_map = {"osram-rgb-led.conf": "OSRAMLED"}
lirc_conf_dir = "/etc/lirc/lircd.conf.d/"


def main():
    """ambibulb configuration script. Execution entry point."""

    # parameters object
    params = configparser.ConfigParser()

    if os.path.exists(config_path):
        params.read(config_path)
    else:
        # default parameters object
        default_params = configparser.ConfigParser()
        default_params["general"] = {
            "with_white": 1,
            "cycle_period": 0.3,
            "source": "lirc",
            "logging_level": 20,
            "cropping_mode": image_compose.CroppingMode.FULL.name
        }
        default_params["lirc"] = {
            "config_path": list(lirc_confpath_id_map.keys())[0],
            "config_id": list(lirc_confpath_id_map.values())[0],
        }
        w.msgbox(
            "Couldn't find config file. Default values are preconfigured."
        )
        params = default_params

    # main menu loop
    while True:
        main_opt_selected = w.menu(
            "Main settings menu.",
            [
                ("0", "General settings."),
                ("1", "LIRC settings."),
                ("2", "Exit."),
            ],
        )[0]

        # cancel is selected
        if main_opt_selected == "":
            quit()

        # general settings is selected
        elif main_opt_selected == "0":
            while True:
                general_opt_selected = w.menu(
                    "General settings menu.",
                    [
                        ("0", "If use white in color detection algoritm. Current: " + params["general"]["with_white"]),
                        ("1", "Enter color detection cycle period. Current: " + params["general"]["cycle_period"]),
                        ("2", "Select light source. Current: " + params["general"]["source"]),
                        ("3", "Select logging level. Current: " + params["general"]["logging_level"]),
                        ("4", "Select screen area to analyze. Current: " + params["general"]["cropping_mode"]),
                        ("5", "Back."),
                    ],
                )[0]

                if general_opt_selected == "0":
                    result = w.yesno(
                        "Use white color in the color detection algoritm?",
                        default="no",
                    )
                    str_result = str(int(not result))
                    params["general"]["with_white"] = str_result

                elif general_opt_selected == "1":
                    result = w.inputbox(
                        "Enter color detection cycle period (sec). Press TAB to switch to yes/no dialog.",
                        default=params["general"]["cycle_period"],
                    )[0]
                    if result == "":
                        w.msgbox("Cycle period was not entered.")
                        continue
                    try:
                        result_float = float(result)
                    except ValueError:
                        w.msgbox("Not correct value: " + result)
                        continue
                    params["general"]["cycle_period"] = str(result_float)

                elif general_opt_selected == "2":
                    result = w.radiolist(
                        "Press SPACE to select light source. Press TAB to switch to yes/no dialog: ",
                        ["lirc"],
                    )[0]
                    if len(result) == 0:
                        w.msgbox("Light source level was not selected.")
                        continue
                    params["general"]["source"] = result[0]
                elif general_opt_selected == "3":
                    result = w.radiolist(
                        "Press SPACE to select logging level. Press TAB to switch to yes/no dialog: ",
                        [
                            "0 - NOTSET",
                            "10 - DEBUG",
                            "20 - INFO",
                            "30 - WARNING",
                            "40 - ERROR",
                            "50 - CRITICAL",
                        ],
                    )[0]
                    if len(result) == 0:
                        w.msgbox("Logging level was not selected.")
                        continue
                    params["general"]["logging_level"] = result[0]
                elif general_opt_selected == "4":
                    result = w.radiolist(
                        "Press SPACE to select screen area to analyze. Press TAB to switch to yes/no dialog: ",
                        [name for name, member in image_compose.CroppingMode.__members__.items()],
                    )[0]
                    if len(result) == 0:
                        w.msgbox("Screen area was not selected.")
                        continue
                    params["general"]["cropping_mode"] = result[0]
                else:
                    # general_opt_selected is "" or "5"
                    # go to main menu
                    break

        # lirc settings
        elif main_opt_selected == "1":
            result = w.inputbox(
                "Enter name of the lirc config: ",
                default=params["lirc"]["config_path"],
            )[0]
            if result == "":
                continue
            if result not in lirc_confpath_id_map.keys():
                w.msgbox("Not supported/valid config: " + result)
                continue
            else:
                params["lirc"]["config_path"] = result
                params["lirc"]["config_id"] = lirc_confpath_id_map[result]

        # exit is selected
        elif main_opt_selected == "2":
            result = w.yesno(
                "Do you want to save the changes in " + config_path + "?",
                default="no",
            )
            # False in case of YES answer
            if result == False:
                lirc_selected_conf_path = os.path.join(
                    lirc_conf_dir, params["lirc"]["config_path"]
                )
                if not os.path.exists(lirc_selected_conf_path):
                    w.msgbox(
                        "WARNING. After configuration is finished, "
                        + "make sure that ambibulb lirc config: "
                        + params["lirc"]["config_path"]
                        + " is copied to lirc config directory: "
                        + lirc_conf_dir
                    )
                else:
                    w.msgbox(
                        "lirc configuration. No actions required,"
                        + " config file already exists: "
                        + lirc_selected_conf_path
                    )
                with open(config_path, "w") as cf:
                    params.write(cf)
            quit()


if __name__ == "__main__":
    main()



# MIT License
# Copyright (c) 2021 Sergey B <dkc.sergey.88@hotmail.com>


from logging import log, DEBUG
import time
from sklearn.cluster import MiniBatchKMeans
import numpy as np


def get_dominant_clr(image):
    """calculates dominant color of input image object.

    Args:
        image: input image object.
    Returns:
        tuple(int, int, int): position of dominant color on RGB plane.
    """
    dominant_color_tic = time.perf_counter()
    # reshape image to 1-dimensional array
    np_image = np.array(image)
    reshaped_image = np_image.reshape(
        (np_image.shape[0] * np_image.shape[1], 3)
    )

    # calculate dominant color
    clt = MiniBatchKMeans(
        n_clusters=1, max_iter=10, verbose=0, compute_labels=False, tol=0.1
    )
    clt.fit(reshaped_image)
    dominant = clt.cluster_centers_.astype("uint8")
    dominant_color_toc = time.perf_counter()
    log(
        DEBUG,
        "dominant color time: "
        + "{:10.4f}".format(dominant_color_toc - dominant_color_tic),
    )
    return dominant[0][0], dominant[0][1], dominant[0][2]



# MIT License
# Copyright (c) 2021 Sergey B <dkc.sergey.88@hotmail.com>


from logging import log, DEBUG
import time
from PIL import Image
from enum import Enum


class CroppingMode(Enum):
    """Defines possible image cropping modes. For example,
    LEFT means that only left part of the image get saved.
    """

    FULL = "FULL"
    LEFT = "LEFT"
    TOP = "TOP"
    RIGHT = "RIGHT"
    BOTTOM = "BOTTOM"


def image_compose(
    raw_image, image_width, image_height, cropping_mode: CroppingMode
):
    """1. Convert binary image blob with given width and height to
    pil-understandable format.
    2. reduce image size while preserving asptect ratio (350x350)
    3. crop the image, keeping only one of the side from original image

    Args:
        raw_image: binary image blob in rgb888 format.
        image_width: image width.
        image_height: image height.
        cropping_mode: cropping mode.
    Returns:
        :py:class:`~PIL.Image.Image` object.: composed image
    """
    # open image
    image_open_tic = time.perf_counter()
    opened_image = Image.frombytes(
        mode="RGB", size=(image_width, image_height), data=raw_image
    )
    image_open_toc = time.perf_counter()
    log(
        DEBUG,
        "image open time: "
        + "{:10.4f}".format(image_open_toc - image_open_tic),
    )

    # resize image
    opened_image.thumbnail((350, 350), Image.BICUBIC)
    image_resize_tic = time.perf_counter()
    log(
        DEBUG,
        "image resize time: "
        + "{:10.4f}".format(image_resize_tic - image_open_toc),
    )

    # crop image if needed
    width, height = opened_image.size
    # default values of cropped image points (0 in top left corner)
    left = 0
    top = 0
    right = width
    bottom = height

    # change point position by keeping 10% from original image
    if cropping_mode == CroppingMode.LEFT:
        right = width / 10
    elif cropping_mode == CroppingMode.TOP:
        bottom = height / 10
    elif cropping_mode == CroppingMode.RIGHT:
        left = 9 * width / 10
    elif cropping_mode == CroppingMode.BOTTOM:
        top = 9 * height / 10
    else:
        pass  # NONE

    cropped_image = opened_image.crop((left, top, right, bottom))
    image_crop_toc = time.perf_counter()
    log(
        DEBUG,
        "image cropping time: "
        + "{:10.4f}".format(image_crop_toc - image_resize_tic),
    )
    return cropped_image


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ambibulb",
    version="0.0.51",
    author="Sergey B",
    license="MIT",
    author_email="dkc.sergey.88@hotmail.com",
    description="Python utility controls the color of RC lights based on the dominant color of an image on your screen.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bespsm/ambibulb",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Topic :: Utilities",
        "Topic :: Multimedia :: Graphics",
        "Topic :: Multimedia :: Graphics :: Capture :: Screen Capture",
    ],
    setup_requires=["cffi>=1.13"],
    cffi_modules=["./snapshot_bcm/cffi_build.py:ffi"],
    install_requires=[
        line.strip() for line in open("./requirements.txt").readlines()
    ],
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "ambibulb=ambibulb.__main__:main",
            "ambibulb-config=ambibulb.ambibulb_config:main",
        ],
    },
    platforms="linux",
    python_requires=">=3.7",
)
